@@ -29,7 +29,7 @@ Producer::Producer( ) :
 {
 }
 
-Producer::Producer( Profile& profile, char *id, char *service ) :
+Producer::Producer( Profile& profile, const char *id, const char *service ) :
 	instance( NULL ),
 	parent_( NULL )
 {
@@ -60,6 +60,7 @@ Producer::Producer( mlt_producer producer ) :
 }
 
 Producer::Producer( Producer &producer ) :
+	Mlt::Service( producer ),
 	instance( producer.get_producer( ) ),
 	parent_( NULL )
 {
