@@ -6,16 +6,19 @@ require 'mltpp'
 # Create the mlt system
 Mltpp::Factory::init
 
+# Establish the mlt profile
+profile = Mltpp::Profile.new
+
 # Get and check the argument
 file = ARGV.shift
 raise "Usage: test.rb file" if file.nil?
 
 # Create the producer
-producer = Mltpp::Factory::producer( file )
+producer = Mltpp::Factory::producer( profile, file )
 raise "Unable to load #{file}" if !producer.is_valid
 
 # Create the consumer
-consumer = Mltpp::Consumer.new( "sdl" )
+consumer = Mltpp::Consumer.new( profile, "sdl" )
 raise "Unable to open sdl consumer" if !consumer.is_valid
 
 # Turn off the default rescaling
